function [] = ssplot(data1, cd, data2)
% SSPLOT makes state space plots of timeseries data
%
% input
%   data1: 2D array of data in which
%       columns are: year.dec, y1, y2 [, more y]
%   cd : structure, control data
%   data2: (optional) 2D array of data in which
%       columns are: year.dec, y1, y2 [, more y]
%           

% made by PT, 6 - 8 Oct 2013 - starting from tsplot
% 11 Oct 13 - added output of Euclidian distance
% =================================================
%
toofewdata = 6; % years with < toofewdata are excluded from plots
%
global prog_name uname
fname = mfilename;
%
fprintf('%s\n', 'Graphing time-series of abundances with ssplot:');
if nargin > 2,
    dflag = getnum('Use first (1) or second (2) data set ?:', 1);
else
    dflag=1;
end
if dflag < 1.5, 
    data=data1; 
    coldat = cd.c1dat; % column for date
    colsv1 = cd.c1sv1; % columns for y variables
    colsv2 = cd.c1sv2;
    z = cd.z1; % y value for zero
    ddes = cd.d1des; % data source/description
    colsvt1 = cd.c1svt1; colsvt2 = cd.c1svt2; % numbers or biomass
else
    data=data2; 
    coldat = cd.c2dat; % column for date
    colsv1 = cd.c2sv1; % columns for y variables
    colsv2 = cd.c2sv2;
    z = cd.z2; % y value for zero
    ddes = cd.d2des;
    colsvt1 = cd.c1svt1; colsvt2 = cd.c1svt2; % numbers or biomass
end
dsv1 = cd.dsv1; % names for variables and units
dsv2 = cd.dsv2;
%
years=unique(floor(data(:,coldat)));
fprintf('%s\n', 'Available years of data are:');
fprintf('%8.0f \n', years');
minyear=min(years); maxyear=max(years);
begin_year=floor(getnum(...
    'Enter (integer) start year for plot :', minyear));
% add 0.999 to integer end_year include whole year
end_year=0.999 + floor(getnum(... 
    'Enter (integer) last full year for plot :', maxyear));
%
% extract reference values
localdata = extract2(cd.refs, cd.refe, z, data, ...
    coldat, colsv1, colsv2, cd.mf);
meref = median(localdata(:,1));
meref(2)= median(localdata(:,2));
meref(3) = median(localdata(:,3));
meref(4) = length(localdata(:,1));

% step through years, calculating medians
medata = zeros(length(years), 5);
r = 1;
for yr = begin_year:end_year,
%    clear localdata
    % call extract2 with raw data; it returns transformed Y1 and Y2
    localdata = extract2(yr, yr, z, data, ...
        coldat, colsv1, colsv2, cd.mf);
    % localdata(:,1) = col 1 = year; 2 = y1;  3 = y2; 4 = month (not used)
    medata(r,1) = median(localdata(:,1)); % year (and decimal) median
    medata(r,2) = median(localdata(:,2)); % y1 median
    medata(r,3) = median(localdata(:,3)); % y2 median
    medata(r,4) = length(localdata(:,1)); % number of data 
    medata(r,5) = sqrt((medata(r,2) - meref(2))^2 ...
        + (medata(r,3) - meref(3))^2); % Euclidian distance
    r=r+1;
end   
% print summary of results
refstr = [num2str(cd.refs) ' to ' num2str(cd.refe)];
fprintf([' \n -- results from ssplot (with ref yrs: ' refstr ')\n']);
fprintf('year       y1 med y2 med n-data Eucl \n');
for j = 1:length(medata(:,1)),
    fprintf('%7.2f %7.2f %7.2f   %u  %7.2f \n', ...
        medata(j,1), medata(j,2), medata(j,3), medata(j,4), medata(j,5));
end
fprintf(' -- years excluded if n < %u \n', toofewdata);
fprintf(' -------------------------- \n');
% arrange to exclude years with too few data
for j = 1:length(medata(:,1)),
    if medata(j,4) < toofewdata,
        medata(j,2) = NaN; medata(j,3) = NaN; medata(j,5) = NaN; end
end
t = medata(:,1); eud = medata(:,5);
y1 = medata(:,2); y2 = medata(:,3);
% set up vector of labels 
ys1 = num2str(floor(medata(:,1)));
ys = ys1(:,3:4);

clf;
%
% prepare scales for medians
maxX = ceil(max([max(y1) max(y2)]));
minX = floor(min([min(y1) min(y2)]));
maxY=maxX; minY = minX;

mess = ' : annual medians';
refmess = [' ref: ' num2str(cd.refs) ' to ' num2str(cd.refe)];
%
lmin = [log10(z) log10(z)]; % for minimum
%
subplot(2, 1, 1); % *** STATE SPACE ****
plot(y1, y2, 'ro-');
hold on
plot(meref(2), meref(3), 'go', 'MarkerFaceColor', 'g'); % reference
plot([minX maxX], [meref(3) meref(3)], 'g-', 'Linewidth', 2);
plot([meref(2) meref(2)], [minY maxY], 'g-', 'Linewidth', 2); 
text(minX, meref(3), ['\fontname{times}\fontsize{12}' refmess], ...
    'Color', 'g', ...
    'VerticalAlignment', 'bottom', 'HorizontalAlignment', 'left');
% only plot minima if in range
if lmin(1) > minX,
    plot([minX maxX], lmin, 'r--', 'LineWidth', 1); % 
    text(lmin(1), lmin(2), '\fontname{times}\fontsize{12} min abundance', ...
    'Color', 'r', ...
    'VerticalAlignment', 'bottom', 'HorizontalAlignment', 'left');
    plot( lmin, [minX maxX], 'r--', 'LineWidth', 1); 
end
title(['\fontname{times}\fontsize{14}' ddes mess]);
xlabel(['\fontname{times}\fontsize{12}log10 of ' dsv1]);
ylabel(['\fontname{times}\fontsize{12}log10 of ' dsv2]);
text(minX+0.1, minY + 0.9*(maxY-minY), ... 
    ['\fontname{times}\fontsize{12}Plotted by ' ...
    prog_name '-' fname ' on ' date] );
% label start and end points - but not if too few data
% text(y1(1), y2(1), ['\fontname{times}\fontsize{12}' ...
%     num2str(floor(meref(1,1))) ], 'HorizontalAlignment', 'left');
text(y1, y2, ys);
axis([minX maxX minY maxY]);
axis square;
grid on;
%
subplot(2,1,2); % *** EUCLIDIAN DISTANCE ***
plot(t,eud, 'ro-');
hold on
plot([cd.refs cd.refs], ylim, 'g-', 'LineWidth', 2);
plot([cd.refe+0.99 cd.refe+0.99], ylim, 'g-', 'LineWidth', 2);
grid on
xlabel('\fontname{times}\fontsize{12}year');
ylabel('\fontname{times}\fontsize{12}log10(cells/L)');
title('\fontname{times}\fontsize{14}Euclidian distance from reference');
%
% output diagram
orient tall; % portrait
cal = fix(clock); 
dayhr = ['-' num2str(cal(3)) '-' num2str(cal(4))];
ofn = strcat(uname, prog_name, '-ss', cd.df1n(1:4), ...
                    num2str(begin_year), dayhr, '.', cd.pt);
switch cd.pt
    case 'ai' 
        print('-dill', ofn); % soon no longer supported by Matlab
    case 'pdf'
        print('-dpdf', ofn);
    case 'ps'
        print('-dpsc2', ofn);
    otherwise
        fprintf('\n%s\n',' ---- printing error');
end % of switch
fprintf('\n%s\n\n', ['===== time-series graph saved as ' ofn]);
%
    
% ==============================================================
function p = getnum(query, default)
% prompts user for a numeric value, with default
% input: query - a string; default - a numeric value
% output: p - a numeric value
p = input([query ' [' num2str(default) ']: ']);
if isempty(p), p = default; end