function [] = ssplot2(data1, cd)
% SSPLOT makes state space plots of timeseries data
%
% input
%   data1: 2D array of data in which
%       columns are: year.dec, y1, y2 [, more y]
%   cd : structure, control data
%           

% made by PT, 6 - 8 Oct 2013 - starting from tsplot
% 11 Oct 13 - added output of Euclidian distance
% 29 July 2014 - SSPLOTTH for Thau paper - NEEDS MORE WORK
% 1 Mar 2015 - outputs ratio data
% 4-5 Sep 2015 - saves figure using PIPRINT and restores euclidian option
% 5 Sep 2015 - renamed as SSPLO2, using only one data-set
% 7 Sep 2015 - revise call of EXTRACT2 (to use z1 and z2)
% 12 Sep 2015 - takes toofewdata from cd
%           --- NEEDS MORE WORK!
% =================================================
%

% toofewdata = 6; % years with < toofewdata are excluded from plots
toofewdata = cd.mindata; % years with < toofewdata are excluded from plots
%
global prog_name uname
fname = mfilename;
%
simplify = 0; % simplify = 1 plots median state-space only

fprintf('%s\n', ['Graphing time-series of abundances with ' fname ':']); 
data=data1; 
coldat = cd.c1dat; % column for date
colsv1 = cd.c1sv1; % columns for y variables
colsv2 = cd.c1sv2;
ddes = cd.d1des; % data source/description
colsvt1 = cd.c1svt1; colsvt2 = cd.c1svt2; % numbers or biomass
dsv1 = cd.dsv1; % names for variables and units
dsv2 = cd.dsv2;
% get appropriate minimum value
if cd.c1svt1 == 1, % data are cell numbers [cells/L]
    z1 = cd.z1; 
    z2 = cd.z2;
else % data are biovolumes (or biomasses - users can chose units)
    z1 = cd.bz1; 
    z2 = cd.bz2;
end
%% YEARS
years=unique(floor(data(:,coldat)));
fprintf('%s\n', 'Available years of data are:');
fprintf('%8.0f \n', years');
minyear=min(years); maxyear=max(years);
begin_year=floor(getnum(...
    'Enter (integer) start year for plot :', minyear));
% add 0.999 to integer end_year include whole year
end_year=0.999 + floor(getnum(... 
    'Enter (integer) last full year for plot :', maxyear));
%
%% extract reference values
localdata = extract2(cd.refs, cd.refe, z1, z2, data, ...
    coldat, colsv1, colsv2, cd.mf); % USING Z1 HERE - CHECK
meref = median(localdata(:,1));
meref(2)= median(localdata(:,2));
meref(3) = median(localdata(:,3));
meref(4) = length(localdata(:,1));

%% step through years, calculating medians
medata = zeros(length(years), 5);
r = 1;
for yr = begin_year:end_year,
%    clear localdata
    % call extract2 with raw data; it returns transformed Y1 and Y2
    localdata = extract2(yr, yr, z1, z2, data, ...
        coldat, colsv1, colsv2, cd.mf); % USING `1 HERE - CHECK
    % localdata(:,1) = col 1 = year; 2 = y1;  3 = y2; 4 = month (not used)
    medata(r,1) = median(localdata(:,1)); % year (and decimal) median
    medata(r,2) = median(localdata(:,2)); % y1 median
    medata(r,3) = median(localdata(:,3)); % y2 median
    medata(r,4) = length(localdata(:,1)); % number of data 
    medata(r,5) = sqrt((medata(r,2) - meref(2))^2 ...
        + (medata(r,3) - meref(3))^2); % Euclidian distance
    r=r+1;
end  

%% NEW 1 MAR 2015 - CALCULATE RATIOS
nlmy1 = 10.^(medata(:,2));
nlmy2 = 10.^(medata(:,3));
medata(:,6) = nlmy1./(nlmy1+nlmy2);

%% print summary of results INCLUDING RATIO OF MEDIANS - 1 MAR 15
refstr = [num2str(cd.refs) ' to ' num2str(cd.refe)];
fprintf([' \n -- results from ssplot (with ref yrs: ' refstr ')\n']);
fprintf(' y1 and y2 log10(y+z), ratio is arith y1/(y1+y2) \n');
fprintf('year       y1 med y2 med n-data  Eucl    ratio \n');
for j = 1:length(medata(:,1)),
    fprintf('%7.2f %7.2f %7.2f   %3u  %7.2f %7.4f \n', ...
        medata(j,1), medata(j,2), medata(j,3), medata(j,4), ...
            medata(j,5), medata(j,6));
end
fprintf(' -- years excluded from plot if n < %u \n', toofewdata);
fprintf(' -------------------------- \n');

%% arrange to exclude years with too few data
for j = 1:length(medata(:,1)),
    if medata(j,4) < toofewdata,
        medata(j,2) = NaN; medata(j,3) = NaN; medata(j,5) = NaN; end
end
t = medata(:,1); eud = medata(:,5);
y1 = medata(:,2); y2 = medata(:,3);

%% set up vector of labels 
ys1 = num2str(floor(medata(:,1)));
ys = ys1(:,3:4); 

%% prepare scales for medians - changes on 1 Mar 2015
%maxX = ceil(max([max(y1) max(y2)]));
%minX = floor(min([min(y1) min(y2)]));
%maxY=maxX; minY = minX;
%minX = 4; maxX = 6;
%minY = 3; maxY = 5;
maxX = ceil(max(y1)); minX = floor(min(y1));
maxY = ceil(max(y2)); minY = floor(min(y2));

mess = ' : annual medians';
refmess = [' ref: ' num2str(cd.refs) ' to ' num2str(cd.refe)];
%
lmin1 = [log10(z1) log10(z1)]; % for minimum
lmin2 = [log10(z2) log10(z2)];
lmin = sqrt(lmin1.^2 + lmin2.^2); % IS THIS (SQUARING LOGS) CORRECT?
%
clf;
if simplify < 0.5, subplot(2, 1, 1); end % for double plot
%% *** STATE SPACE ****
plot(y1, y2, 'ko', 'MarkerFaceColor', 'k');
hold on
plot(meref(2), meref(3), 'ks', 'MarkerFaceColor', 'k', ...
    'MarkerSize', 10); % reference
plot([minX maxX], [meref(3) meref(3)], 'k--', 'Linewidth', 2);
plot([meref(2) meref(2)], [minY maxY], 'k--', 'Linewidth', 2); 
text(maxX, meref(3), ['\fontname{arial}\fontsize{12}' refmess], ...
    'Color', 'k', ...
    'VerticalAlignment', 'bottom', 'HorizontalAlignment', 'right');
% only plot minima if in range
% if lmin(1) > minX,
%     plot([minX maxX], lmin, 'r--', 'LineWidth', 1); % 
%     text(lmin(1), lmin(2), '\fontname{times}\fontsize{12} min abundance', ...
%     'Color', 'r', ...
%     'VerticalAlignment', 'bottom', 'HorizontalAlignment', 'left');
%     plot( lmin, [minX maxX], 'r--', 'LineWidth', 1); 
% end
%title(['\fontname{times}\fontsize{14}' ddes mess]);
xlabel(['\fontname{times}\fontsize{18}log_{10}(' dsv1 ')']);
ylabel(['\fontname{times}\fontsize{18}log_{10}(' dsv2 ')']);
%text(minX+0.1, minY + 0.9*(maxY-minY), ... 
%    ['\fontname{times}\fontsize{12}Plotted by ' ...
%    prog_name '-' fname ' on ' date] );
% label start and end points - but not if too few data
% text(y1(1), y2(1), ['\fontname{times}\fontsize{12}' ...
%     num2str(floor(meref(1,1))) ], 'HorizontalAlignment', 'left');
text(y1+0.05, y2, ys, 'FontName', 'Arial', 'FontSize', 12 );
axis([minX maxX minY maxY]);
axis square;
grid on;
% set(gca, 'YTick', [3.0, 3.5, 4.0, 4.5, 5.0]);
% set(gca, 'XTick', [4.0, 4.5, 5.0, 5.5, 6.0]);
% set(gca,'XTickLabel',{'4.0','4.5','5.0','5.5','6.0'}, ...
%     'FontName', 'Arial', 'FontSize', 12);
% set(gca,'YTickLabel',{'3.0','3.5','4.0','4.5','5.0'}, ...
%     'FontName', 'Arial', 'FontSize', 12);
%
if simplify < 0.5, % then double plot
%% *** EUCLIDIAN DISTANCE ***
    subplot(2,1,2); 
    plot(t,eud, 'ro-');
    hold on
    plot([cd.refs cd.refs], ylim, 'g--', 'LineWidth', 2);
    plot([cd.refe+0.99 cd.refe+0.99], ylim, 'g--', 'LineWidth', 2);
    grid on
    xlabel('\fontname{times}\fontsize{12}year');
    ylabel('\fontname{times}\fontsize{12}log10(cells/L)');
    title(...
        '\fontname{times}\fontsize{14}Euclidian distance from reference');
    axis square; % to match the top plot
end
%

%% output diagram using PIPrint
% ori = 1; selects for 'tall' orientation; ori = 0; selects for 'portrait'
if simplify < 0.5, ori = 1; else ori = 0; end
ofn = strcat(uname, prog_name, '-ss', cd.df1n(1:4), num2str(begin_year));
PIPrint (cd.pt, ofn, 'state space medians graph', ori);
%
    
% ==============================================================
function p = getnum(query, default)
% prompts user for a numeric value, with default
% input: query - a string; default - a numeric value
% output: p - a numeric value
p = input([query ' [' num2str(default) ']: ']);
if isempty(p), p = default; end